@@ -4,7 +4,7 @@ from unittest import mock
 
 import pytest
 
-from hcloud.actions import BoundAction
+from hcloud import Client
 from hcloud.firewalls import (
     BoundFirewall,
     Firewall,
@@ -18,8 +18,8 @@ from hcloud.servers import Server
 
 class TestBoundFirewall:
     @pytest.fixture()
-    def bound_firewall(self, hetzner_client):
-        return BoundFirewall(client=hetzner_client.firewalls, data=dict(id=1))
+    def bound_firewall(self, client: Client):
+        return BoundFirewall(client.firewalls, data=dict(id=1))
 
     def test_bound_firewall_init(self, firewall_response):
         bound_firewall = BoundFirewall(
@@ -71,68 +71,49 @@ class TestBoundFirewall:
         ]
         assert firewall_out_rule.description == "allow http out"
 
-    @pytest.mark.parametrize(
-        "params", [{}, {"sort": ["created"], "page": 1, "per_page": 2}]
-    )
-    def test_get_actions_list(
-        self, hetzner_client, bound_firewall, response_get_actions, params
+    def test_update(
+        self,
+        request_mock: mock.MagicMock,
+        bound_firewall,
+        response_update_firewall,
     ):
-        hetzner_client.request.return_value = response_get_actions
-        result = bound_firewall.get_actions_list(**params)
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1/actions", method="GET", params=params
-        )
+        request_mock.return_value = response_update_firewall
 
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == hetzner_client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "set_firewall_rules"
-
-    @pytest.mark.parametrize("params", [{}, {"sort": ["created"]}])
-    def test_get_actions(
-        self, hetzner_client, bound_firewall, response_get_actions, params
-    ):
-        hetzner_client.request.return_value = response_get_actions
-        actions = bound_firewall.get_actions(**params)
-
-        params.update({"page": 1, "per_page": 50})
-
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1/actions", method="GET", params=params
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == hetzner_client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "set_firewall_rules"
-
-    def test_update(self, hetzner_client, bound_firewall, response_update_firewall):
-        hetzner_client.request.return_value = response_update_firewall
         firewall = bound_firewall.update(
             name="New Corporate Intranet Protection", labels={}
         )
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1",
+
+        request_mock.assert_called_with(
             method="PUT",
+            url="/firewalls/1",
             json={"name": "New Corporate Intranet Protection", "labels": {}},
         )
 
         assert firewall.id == 38
         assert firewall.name == "New Corporate Intranet Protection"
 
-    def test_delete(self, hetzner_client, bound_firewall):
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        bound_firewall,
+    ):
         delete_success = bound_firewall.delete()
-        hetzner_client.request.assert_called_with(url="/firewalls/1", method="DELETE")
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/firewalls/1",
+        )
 
         assert delete_success is True
 
-    def test_set_rules(self, hetzner_client, bound_firewall, response_set_rules):
-        hetzner_client.request.return_value = response_set_rules
+    def test_set_rules(
+        self,
+        request_mock: mock.MagicMock,
+        bound_firewall,
+        response_set_rules,
+    ):
+        request_mock.return_value = response_set_rules
+
         actions = bound_firewall.set_rules(
             [
                 FirewallRule(
@@ -143,9 +124,10 @@ class TestBoundFirewall:
                 )
             ]
         )
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1/actions/set_rules",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/set_rules",
             json={
                 "rules": [
                     {
@@ -162,15 +144,20 @@ class TestBoundFirewall:
         assert actions[0].progress == 100
 
     def test_apply_to_resources(
-        self, hetzner_client, bound_firewall, response_set_rules
+        self,
+        request_mock: mock.MagicMock,
+        bound_firewall,
+        response_set_rules,
     ):
-        hetzner_client.request.return_value = response_set_rules
+        request_mock.return_value = response_set_rules
+
         actions = bound_firewall.apply_to_resources(
             [FirewallResource(type=FirewallResource.TYPE_SERVER, server=Server(id=5))]
         )
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1/actions/apply_to_resources",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/apply_to_resources",
             json={"apply_to": [{"type": "server", "server": {"id": 5}}]},
         )
 
@@ -178,15 +165,20 @@ class TestBoundFirewall:
         assert actions[0].progress == 100
 
     def test_remove_from_resources(
-        self, hetzner_client, bound_firewall, response_set_rules
+        self,
+        request_mock: mock.MagicMock,
+        bound_firewall,
+        response_set_rules,
     ):
-        hetzner_client.request.return_value = response_set_rules
+        request_mock.return_value = response_set_rules
+
         actions = bound_firewall.remove_from_resources(
             [FirewallResource(type=FirewallResource.TYPE_SERVER, server=Server(id=5))]
         )
-        hetzner_client.request.assert_called_with(
-            url="/firewalls/1/actions/remove_from_resources",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/remove_from_resources",
             json={"remove_from": [{"type": "server", "server": {"id": 5}}]},
         )
 
@@ -196,14 +188,22 @@ class TestBoundFirewall:
 
 class TestFirewallsClient:
     @pytest.fixture()
-    def firewalls_client(self):
-        return FirewallsClient(client=mock.MagicMock())
+    def firewalls_client(self, client: Client):
+        return FirewallsClient(client)
+
+    def test_get_by_id(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall_response,
+    ):
+        request_mock.return_value = firewall_response
 
-    def test_get_by_id(self, firewalls_client, firewall_response):
-        firewalls_client._client.request.return_value = firewall_response
         firewall = firewalls_client.get_by_id(1)
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1", method="GET"
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/firewalls/1",
         )
         assert firewall._client is firewalls_client
         assert firewall.id == 38
@@ -223,11 +223,21 @@ class TestFirewallsClient:
             {},
         ],
     )
-    def test_get_list(self, firewalls_client, two_firewalls_response, params):
-        firewalls_client._client.request.return_value = two_firewalls_response
+    def test_get_list(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        two_firewalls_response,
+        params,
+    ):
+        request_mock.return_value = two_firewalls_response
+
         result = firewalls_client.get_list(**params)
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls", method="GET", params=params
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/firewalls",
+            params=params,
         )
 
         firewalls = result.firewalls
@@ -257,14 +267,23 @@ class TestFirewallsClient:
             {},
         ],
     )
-    def test_get_all(self, firewalls_client, two_firewalls_response, params):
-        firewalls_client._client.request.return_value = two_firewalls_response
+    def test_get_all(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        two_firewalls_response,
+        params,
+    ):
+        request_mock.return_value = two_firewalls_response
+
         firewalls = firewalls_client.get_all(**params)
 
         params.update({"page": 1, "per_page": 50})
 
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls", method="GET", params=params
+        request_mock.assert_called_with(
+            method="GET",
+            url="/firewalls",
+            params=params,
         )
 
         assert len(firewalls) == 2
@@ -280,42 +299,36 @@ class TestFirewallsClient:
         assert firewalls2.id == 39
         assert firewalls2.name == "Corporate Extranet Protection"
 
-    def test_get_by_name(self, firewalls_client, one_firewalls_response):
-        firewalls_client._client.request.return_value = one_firewalls_response
+    def test_get_by_name(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        one_firewalls_response,
+    ):
+        request_mock.return_value = one_firewalls_response
+
         firewall = firewalls_client.get_by_name("Corporate Intranet Protection")
 
         params = {"name": "Corporate Intranet Protection"}
 
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls", method="GET", params=params
+        request_mock.assert_called_with(
+            method="GET",
+            url="/firewalls",
+            params=params,
         )
 
         assert firewall._client is firewalls_client
         assert firewall.id == 38
         assert firewall.name == "Corporate Intranet Protection"
 
-    @pytest.mark.parametrize(
-        "firewall", [Firewall(id=1), BoundFirewall(mock.MagicMock(), dict(id=1))]
-    )
-    def test_get_actions_list(self, firewalls_client, firewall, response_get_actions):
-        firewalls_client._client.request.return_value = response_get_actions
-        result = firewalls_client.get_actions_list(firewall)
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1/actions", method="GET", params={}
-        )
+    def test_create(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        response_create_firewall,
+    ):
+        request_mock.return_value = response_create_firewall
 
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-
-        assert actions[0]._client == firewalls_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "set_firewall_rules"
-
-    def test_create(self, firewalls_client, response_create_firewall):
-        firewalls_client._client.request.return_value = response_create_firewall
         response = firewalls_client.create(
             "Corporate Intranet Protection",
             rules=[
@@ -335,9 +348,10 @@ class TestFirewallsClient:
                 ),
             ],
         )
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls",
             json={
                 "name": "Corporate Intranet Protection",
                 "rules": [
@@ -366,14 +380,22 @@ class TestFirewallsClient:
     @pytest.mark.parametrize(
         "firewall", [Firewall(id=38), BoundFirewall(mock.MagicMock(), dict(id=38))]
     )
-    def test_update(self, firewalls_client, firewall, response_update_firewall):
-        firewalls_client._client.request.return_value = response_update_firewall
+    def test_update(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall,
+        response_update_firewall,
+    ):
+        request_mock.return_value = response_update_firewall
+
         firewall = firewalls_client.update(
             firewall, name="New Corporate Intranet Protection", labels={}
         )
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/38",
+
+        request_mock.assert_called_with(
             method="PUT",
+            url="/firewalls/38",
             json={"name": "New Corporate Intranet Protection", "labels": {}},
         )
 
@@ -383,8 +405,15 @@ class TestFirewallsClient:
     @pytest.mark.parametrize(
         "firewall", [Firewall(id=1), BoundFirewall(mock.MagicMock(), dict(id=1))]
     )
-    def test_set_rules(self, firewalls_client, firewall, response_set_rules):
-        firewalls_client._client.request.return_value = response_set_rules
+    def test_set_rules(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall,
+        response_set_rules,
+    ):
+        request_mock.return_value = response_set_rules
+
         actions = firewalls_client.set_rules(
             firewall,
             [
@@ -395,9 +424,10 @@ class TestFirewallsClient:
                 )
             ],
         )
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1/actions/set_rules",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/set_rules",
             json={
                 "rules": [
                     {
@@ -415,10 +445,17 @@ class TestFirewallsClient:
     @pytest.mark.parametrize(
         "firewall", [Firewall(id=1), BoundFirewall(mock.MagicMock(), dict(id=1))]
     )
-    def test_delete(self, firewalls_client, firewall):
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall,
+    ):
         delete_success = firewalls_client.delete(firewall)
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1", method="DELETE"
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/firewalls/1",
         )
 
         assert delete_success is True
@@ -426,16 +463,23 @@ class TestFirewallsClient:
     @pytest.mark.parametrize(
         "firewall", [Firewall(id=1), BoundFirewall(mock.MagicMock(), dict(id=1))]
     )
-    def test_apply_to_resources(self, firewalls_client, firewall, response_set_rules):
-        firewalls_client._client.request.return_value = response_set_rules
+    def test_apply_to_resources(
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall,
+        response_set_rules,
+    ):
+        request_mock.return_value = response_set_rules
 
         actions = firewalls_client.apply_to_resources(
             firewall,
             [FirewallResource(type=FirewallResource.TYPE_SERVER, server=Server(id=5))],
         )
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1/actions/apply_to_resources",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/apply_to_resources",
             json={"apply_to": [{"type": "server", "server": {"id": 5}}]},
         )
 
@@ -446,69 +490,24 @@ class TestFirewallsClient:
         "firewall", [Firewall(id=1), BoundFirewall(mock.MagicMock(), dict(id=1))]
     )
     def test_remove_from_resources(
-        self, firewalls_client, firewall, response_set_rules
+        self,
+        request_mock: mock.MagicMock,
+        firewalls_client: FirewallsClient,
+        firewall,
+        response_set_rules,
     ):
-        firewalls_client._client.request.return_value = response_set_rules
+        request_mock.return_value = response_set_rules
 
         actions = firewalls_client.remove_from_resources(
             firewall,
             [FirewallResource(type=FirewallResource.TYPE_SERVER, server=Server(id=5))],
         )
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/1/actions/remove_from_resources",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/firewalls/1/actions/remove_from_resources",
             json={"remove_from": [{"type": "server", "server": {"id": 5}}]},
         )
 
         assert actions[0].id == 13
         assert actions[0].progress == 100
-
-    def test_actions_get_by_id(self, firewalls_client, response_get_actions):
-        firewalls_client._client.request.return_value = {
-            "action": response_get_actions["actions"][0]
-        }
-        action = firewalls_client.actions.get_by_id(13)
-
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/actions/13", method="GET"
-        )
-
-        assert isinstance(action, BoundAction)
-        assert action._client == firewalls_client._client.actions
-        assert action.id == 13
-        assert action.command == "set_firewall_rules"
-
-    def test_actions_get_list(self, firewalls_client, response_get_actions):
-        firewalls_client._client.request.return_value = response_get_actions
-        result = firewalls_client.actions.get_list()
-
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/actions",
-            method="GET",
-            params={},
-        )
-
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == firewalls_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "set_firewall_rules"
-
-    def test_actions_get_all(self, firewalls_client, response_get_actions):
-        firewalls_client._client.request.return_value = response_get_actions
-        actions = firewalls_client.actions.get_all()
-
-        firewalls_client._client.request.assert_called_with(
-            url="/firewalls/actions",
-            method="GET",
-            params={"page": 1, "per_page": 50},
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == firewalls_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "set_firewall_rules"
