@@ -4,7 +4,7 @@ from unittest import mock
 
 import pytest
 
-from hcloud.actions import BoundAction
+from hcloud import Client
 from hcloud.floating_ips import BoundFloatingIP, FloatingIP, FloatingIPsClient
 from hcloud.locations import BoundLocation, Location
 from hcloud.servers import BoundServer, Server
@@ -12,8 +12,8 @@ from hcloud.servers import BoundServer, Server
 
 class TestBoundFloatingIP:
     @pytest.fixture()
-    def bound_floating_ip(self, hetzner_client):
-        return BoundFloatingIP(client=hetzner_client.floating_ips, data=dict(id=14))
+    def bound_floating_ip(self, client: Client):
+        return BoundFloatingIP(client.floating_ips, data=dict(id=14))
 
     def test_bound_floating_ip_init(self, floating_ip_response):
         bound_floating_ip = BoundFloatingIP(
@@ -41,31 +41,21 @@ class TestBoundFloatingIP:
         assert bound_floating_ip.home_location.latitude == 50.47612
         assert bound_floating_ip.home_location.longitude == 12.370071
 
-    def test_get_actions(self, hetzner_client, bound_floating_ip, response_get_actions):
-        hetzner_client.request.return_value = response_get_actions
-        actions = bound_floating_ip.get_actions(sort="id")
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14/actions",
-            method="GET",
-            params={"sort": "id", "page": 1, "per_page": 50},
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == hetzner_client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "assign_floating_ip"
-
     def test_update(
-        self, hetzner_client, bound_floating_ip, response_update_floating_ip
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        response_update_floating_ip,
     ):
-        hetzner_client.request.return_value = response_update_floating_ip
+        request_mock.return_value = response_update_floating_ip
+
         floating_ip = bound_floating_ip.update(
             description="New description", name="New name"
         )
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14",
+
+        request_mock.assert_called_with(
             method="PUT",
+            url="/floating_ips/14",
             json={"description": "New description", "name": "New name"},
         )
 
@@ -73,21 +63,36 @@ class TestBoundFloatingIP:
         assert floating_ip.description == "New description"
         assert floating_ip.name == "New name"
 
-    def test_delete(self, hetzner_client, bound_floating_ip, generic_action):
-        hetzner_client.request.return_value = generic_action
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         delete_success = bound_floating_ip.delete()
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14", method="DELETE"
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/floating_ips/14",
         )
 
         assert delete_success is True
 
-    def test_change_protection(self, hetzner_client, bound_floating_ip, generic_action):
-        hetzner_client.request.return_value = generic_action
+    def test_change_protection(
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = bound_floating_ip.change_protection(True)
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14/actions/change_protection",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips/14/actions/change_protection",
             json={"delete": True},
         )
 
@@ -97,30 +102,55 @@ class TestBoundFloatingIP:
     @pytest.mark.parametrize(
         "server", (Server(id=1), BoundServer(mock.MagicMock(), dict(id=1)))
     )
-    def test_assign(self, hetzner_client, bound_floating_ip, server, generic_action):
-        hetzner_client.request.return_value = generic_action
+    def test_assign(
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        server,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = bound_floating_ip.assign(server)
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14/actions/assign", method="POST", json={"server": 1}
-        )
-        assert action.id == 1
-        assert action.progress == 0
 
-    def test_unassign(self, hetzner_client, bound_floating_ip, generic_action):
-        hetzner_client.request.return_value = generic_action
-        action = bound_floating_ip.unassign()
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14/actions/unassign", method="POST"
-        )
-        assert action.id == 1
-        assert action.progress == 0
-
-    def test_change_dns_ptr(self, hetzner_client, bound_floating_ip, generic_action):
-        hetzner_client.request.return_value = generic_action
-        action = bound_floating_ip.change_dns_ptr("1.2.3.4", "server02.example.com")
-        hetzner_client.request.assert_called_with(
-            url="/floating_ips/14/actions/change_dns_ptr",
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips/14/actions/assign",
+            json={"server": 1},
+        )
+        assert action.id == 1
+        assert action.progress == 0
+
+    def test_unassign(
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
+        action = bound_floating_ip.unassign()
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/floating_ips/14/actions/unassign",
+        )
+        assert action.id == 1
+        assert action.progress == 0
+
+    def test_change_dns_ptr(
+        self,
+        request_mock: mock.MagicMock,
+        bound_floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
+        action = bound_floating_ip.change_dns_ptr("1.2.3.4", "server02.example.com")
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/floating_ips/14/actions/change_dns_ptr",
             json={"ip": "1.2.3.4", "dns_ptr": "server02.example.com"},
         )
         assert action.id == 1
@@ -129,24 +159,41 @@ class TestBoundFloatingIP:
 
 class TestFloatingIPsClient:
     @pytest.fixture()
-    def floating_ips_client(self):
-        return FloatingIPsClient(client=mock.MagicMock())
+    def floating_ips_client(self, client: Client):
+        return FloatingIPsClient(client)
+
+    def test_get_by_id(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip_response,
+    ):
+        request_mock.return_value = floating_ip_response
 
-    def test_get_by_id(self, floating_ips_client, floating_ip_response):
-        floating_ips_client._client.request.return_value = floating_ip_response
         bound_floating_ip = floating_ips_client.get_by_id(1)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/1", method="GET"
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/floating_ips/1",
         )
         assert bound_floating_ip._client is floating_ips_client
         assert bound_floating_ip.id == 4711
         assert bound_floating_ip.description == "Web Frontend"
 
-    def test_get_by_name(self, floating_ips_client, one_floating_ips_response):
-        floating_ips_client._client.request.return_value = one_floating_ips_response
+    def test_get_by_name(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        one_floating_ips_response,
+    ):
+        request_mock.return_value = one_floating_ips_response
+
         bound_floating_ip = floating_ips_client.get_by_name("Web Frontend")
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips", method="GET", params={"name": "Web Frontend"}
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/floating_ips",
+            params={"name": "Web Frontend"},
         )
         assert bound_floating_ip._client is floating_ips_client
         assert bound_floating_ip.id == 4711
@@ -157,11 +204,21 @@ class TestFloatingIPsClient:
         "params",
         [{"label_selector": "label1", "page": 1, "per_page": 10}, {"name": ""}, {}],
     )
-    def test_get_list(self, floating_ips_client, two_floating_ips_response, params):
-        floating_ips_client._client.request.return_value = two_floating_ips_response
+    def test_get_list(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        two_floating_ips_response,
+        params,
+    ):
+        request_mock.return_value = two_floating_ips_response
+
         result = floating_ips_client.get_list(**params)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips", method="GET", params=params
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/floating_ips",
+            params=params,
         )
 
         bound_floating_ips = result.floating_ips
@@ -181,14 +238,23 @@ class TestFloatingIPsClient:
         assert bound_floating_ip2.description == "Web Backend"
 
     @pytest.mark.parametrize("params", [{"label_selector": "label1"}, {}])
-    def test_get_all(self, floating_ips_client, two_floating_ips_response, params):
-        floating_ips_client._client.request.return_value = two_floating_ips_response
+    def test_get_all(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        two_floating_ips_response,
+        params,
+    ):
+        request_mock.return_value = two_floating_ips_response
+
         bound_floating_ips = floating_ips_client.get_all(**params)
 
         params.update({"page": 1, "per_page": 50})
 
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips", method="GET", params=params
+        request_mock.assert_called_with(
+            method="GET",
+            url="/floating_ips",
+            params=params,
         )
 
         assert len(bound_floating_ips) == 2
@@ -204,14 +270,21 @@ class TestFloatingIPsClient:
         assert bound_floating_ip2.id == 4712
         assert bound_floating_ip2.description == "Web Backend"
 
-    def test_create_with_location(self, floating_ips_client, floating_ip_response):
-        floating_ips_client._client.request.return_value = floating_ip_response
+    def test_create_with_location(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip_response,
+    ):
+        request_mock.return_value = floating_ip_response
+
         response = floating_ips_client.create(
             "ipv6", "Web Frontend", home_location=Location(name="location")
         )
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips",
             json={
                 "description": "Web Frontend",
                 "type": "ipv6",
@@ -231,15 +304,21 @@ class TestFloatingIPsClient:
         "server", [Server(id=1), BoundServer(mock.MagicMock(), dict(id=1))]
     )
     def test_create_with_server(
-        self, floating_ips_client, server, floating_ip_create_response
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        server,
+        floating_ip_create_response,
     ):
-        floating_ips_client._client.request.return_value = floating_ip_create_response
+        request_mock.return_value = floating_ip_create_response
+
         response = floating_ips_client.create(
             type="ipv6", description="Web Frontend", server=server
         )
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips",
             json={"description": "Web Frontend", "type": "ipv6", "server": 1},
         )
         bound_floating_ip = response.floating_ip
@@ -254,15 +333,21 @@ class TestFloatingIPsClient:
         "server", [Server(id=1), BoundServer(mock.MagicMock(), dict(id=1))]
     )
     def test_create_with_name(
-        self, floating_ips_client, server, floating_ip_create_response
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        server,
+        floating_ip_create_response,
     ):
-        floating_ips_client._client.request.return_value = floating_ip_create_response
+        request_mock.return_value = floating_ip_create_response
+
         response = floating_ips_client.create(
             type="ipv6", description="Web Frontend", name="Web Frontend"
         )
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips",
             json={
                 "description": "Web Frontend",
                 "type": "ipv6",
@@ -278,38 +363,25 @@ class TestFloatingIPsClient:
         assert bound_floating_ip.name == "Web Frontend"
         assert action.id == 13
 
-    @pytest.mark.parametrize(
-        "floating_ip", [FloatingIP(id=1), BoundFloatingIP(mock.MagicMock(), dict(id=1))]
-    )
-    def test_get_actions(self, floating_ips_client, floating_ip, response_get_actions):
-        floating_ips_client._client.request.return_value = response_get_actions
-        actions = floating_ips_client.get_actions(floating_ip)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/1/actions",
-            method="GET",
-            params={"page": 1, "per_page": 50},
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-
-        assert actions[0]._client == floating_ips_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "assign_floating_ip"
-
     @pytest.mark.parametrize(
         "floating_ip", [FloatingIP(id=1), BoundFloatingIP(mock.MagicMock(), dict(id=1))]
     )
     def test_update(
-        self, floating_ips_client, floating_ip, response_update_floating_ip
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip,
+        response_update_floating_ip,
     ):
-        floating_ips_client._client.request.return_value = response_update_floating_ip
+        request_mock.return_value = response_update_floating_ip
+
         floating_ip = floating_ips_client.update(
             floating_ip, description="New description", name="New name"
         )
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/1",
+
+        request_mock.assert_called_with(
             method="PUT",
+            url="/floating_ips/1",
             json={"description": "New description", "name": "New name"},
         )
 
@@ -320,12 +392,20 @@ class TestFloatingIPsClient:
     @pytest.mark.parametrize(
         "floating_ip", [FloatingIP(id=1), BoundFloatingIP(mock.MagicMock(), dict(id=1))]
     )
-    def test_change_protection(self, floating_ips_client, floating_ip, generic_action):
-        floating_ips_client._client.request.return_value = generic_action
+    def test_change_protection(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = floating_ips_client.change_protection(floating_ip, True)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/1/actions/change_protection",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips/1/actions/change_protection",
             json={"delete": True},
         )
 
@@ -335,11 +415,20 @@ class TestFloatingIPsClient:
     @pytest.mark.parametrize(
         "floating_ip", [FloatingIP(id=1), BoundFloatingIP(mock.MagicMock(), dict(id=1))]
     )
-    def test_delete(self, floating_ips_client, floating_ip, generic_action):
-        floating_ips_client._client.request.return_value = generic_action
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         delete_success = floating_ips_client.delete(floating_ip)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/1", method="DELETE"
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/floating_ips/1",
         )
 
         assert delete_success is True
@@ -354,11 +443,22 @@ class TestFloatingIPsClient:
             ),
         ],
     )
-    def test_assign(self, floating_ips_client, server, floating_ip, generic_action):
-        floating_ips_client._client.request.return_value = generic_action
+    def test_assign(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        server,
+        floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = floating_ips_client.assign(floating_ip, server)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/12/actions/assign", method="POST", json={"server": 1}
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/floating_ips/12/actions/assign",
+            json={"server": 1},
         )
         assert action.id == 1
         assert action.progress == 0
@@ -367,11 +467,20 @@ class TestFloatingIPsClient:
         "floating_ip",
         [FloatingIP(id=12), BoundFloatingIP(mock.MagicMock(), dict(id=12))],
     )
-    def test_unassign(self, floating_ips_client, floating_ip, generic_action):
-        floating_ips_client._client.request.return_value = generic_action
+    def test_unassign(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = floating_ips_client.unassign(floating_ip)
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/12/actions/unassign", method="POST"
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/floating_ips/12/actions/unassign",
         )
         assert action.id == 1
         assert action.progress == 0
@@ -380,65 +489,23 @@ class TestFloatingIPsClient:
         "floating_ip",
         [FloatingIP(id=12), BoundFloatingIP(mock.MagicMock(), dict(id=12))],
     )
-    def test_change_dns_ptr(self, floating_ips_client, floating_ip, generic_action):
-        floating_ips_client._client.request.return_value = generic_action
+    def test_change_dns_ptr(
+        self,
+        request_mock: mock.MagicMock,
+        floating_ips_client: FloatingIPsClient,
+        floating_ip,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = floating_ips_client.change_dns_ptr(
             floating_ip, "1.2.3.4", "server02.example.com"
         )
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/12/actions/change_dns_ptr",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/floating_ips/12/actions/change_dns_ptr",
             json={"ip": "1.2.3.4", "dns_ptr": "server02.example.com"},
         )
         assert action.id == 1
         assert action.progress == 0
-
-    def test_actions_get_by_id(self, floating_ips_client, response_get_actions):
-        floating_ips_client._client.request.return_value = {
-            "action": response_get_actions["actions"][0]
-        }
-        action = floating_ips_client.actions.get_by_id(13)
-
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/actions/13", method="GET"
-        )
-
-        assert isinstance(action, BoundAction)
-        assert action._client == floating_ips_client._client.actions
-        assert action.id == 13
-        assert action.command == "assign_floating_ip"
-
-    def test_actions_get_list(self, floating_ips_client, response_get_actions):
-        floating_ips_client._client.request.return_value = response_get_actions
-        result = floating_ips_client.actions.get_list()
-
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/actions",
-            method="GET",
-            params={},
-        )
-
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == floating_ips_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "assign_floating_ip"
-
-    def test_actions_get_all(self, floating_ips_client, response_get_actions):
-        floating_ips_client._client.request.return_value = response_get_actions
-        actions = floating_ips_client.actions.get_all()
-
-        floating_ips_client._client.request.assert_called_with(
-            url="/floating_ips/actions",
-            method="GET",
-            params={"page": 1, "per_page": 50},
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == floating_ips_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "assign_floating_ip"
