@@ -4,7 +4,7 @@ from unittest import mock
 
 import pytest
 
-from hcloud.actions import BoundAction
+from hcloud import Client
 from hcloud.load_balancer_types import LoadBalancerType
 from hcloud.load_balancers import (
     BoundLoadBalancer,
@@ -24,8 +24,8 @@ from hcloud.servers import Server
 
 class TestBoundLoadBalancer:
     @pytest.fixture()
-    def bound_load_balancer(self, hetzner_client):
-        return BoundLoadBalancer(client=hetzner_client.load_balancers, data=dict(id=14))
+    def bound_load_balancer(self, client: Client):
+        return BoundLoadBalancer(client.load_balancers, data=dict(id=14))
 
     def test_bound_load_balancer_init(self, response_load_balancer):
         bound_load_balancer = BoundLoadBalancer(
@@ -35,82 +35,59 @@ class TestBoundLoadBalancer:
         assert bound_load_balancer.id == 4711
         assert bound_load_balancer.name == "Web Frontend"
 
-    @pytest.mark.parametrize("params", [{"page": 1, "per_page": 10}, {}])
-    def test_get_actions_list(
-        self, hetzner_client, bound_load_balancer, response_get_actions, params
-    ):
-        hetzner_client.request.return_value = response_get_actions
-        result = bound_load_balancer.get_actions_list(**params)
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions", method="GET", params=params
-        )
-
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == hetzner_client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "change_protection"
-
-    @pytest.mark.parametrize("params", [{}])
-    def test_get_actions(
-        self, hetzner_client, bound_load_balancer, response_get_actions, params
-    ):
-        hetzner_client.request.return_value = response_get_actions
-        actions = bound_load_balancer.get_actions(**params)
-
-        params.update({"page": 1, "per_page": 50})
-
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions", method="GET", params=params
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == hetzner_client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "change_protection"
-
     def test_update(
-        self, hetzner_client, bound_load_balancer, response_update_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_update_load_balancer,
     ):
-        hetzner_client.request.return_value = response_update_load_balancer
+        request_mock.return_value = response_update_load_balancer
+
         load_balancer = bound_load_balancer.update(name="new-name", labels={})
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14",
+
+        request_mock.assert_called_with(
             method="PUT",
+            url="/load_balancers/14",
             json={"name": "new-name", "labels": {}},
         )
 
         assert load_balancer.id == 4711
         assert load_balancer.name == "new-name"
 
-    def test_delete(self, hetzner_client, generic_action, bound_load_balancer):
-        hetzner_client.request.return_value = generic_action
+    def test_delete(
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         delete_success = bound_load_balancer.delete()
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14", method="DELETE"
+
+        request_mock.assert_called_with(
+            method="DELETE",
+            url="/load_balancers/14",
         )
 
         assert delete_success is True
 
     def test_get_metrics(
         self,
-        hetzner_client,
-        response_get_metrics,
+        request_mock: mock.MagicMock,
         bound_load_balancer: BoundLoadBalancer,
+        response_get_metrics,
     ):
-        hetzner_client.request.return_value = response_get_metrics
+        request_mock.return_value = response_get_metrics
+
         response = bound_load_balancer.get_metrics(
             type=["requests_per_second"],
             start="2023-12-14T16:55:32+01:00",
             end="2023-12-14T16:55:32+01:00",
         )
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/metrics",
+
+        request_mock.assert_called_with(
             method="GET",
+            url="/load_balancers/14/metrics",
             params={
                 "type": "requests_per_second",
                 "start": "2023-12-14T16:55:32+01:00",
@@ -121,15 +98,20 @@ class TestBoundLoadBalancer:
         assert len(response.metrics.time_series["requests_per_second"]["values"]) == 3
 
     def test_add_service(
-        self, hetzner_client, response_add_service, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_add_service,
     ):
-        hetzner_client.request.return_value = response_add_service
+        request_mock.return_value = response_add_service
+
         service = LoadBalancerService(listen_port=80, protocol="http")
         action = bound_load_balancer.add_service(service)
-        hetzner_client.request.assert_called_with(
-            json={"protocol": "http", "listen_port": 80},
-            url="/load_balancers/14/actions/add_service",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/add_service",
+            json={"protocol": "http", "listen_port": 80},
         )
 
         assert action.id == 13
@@ -137,15 +119,20 @@ class TestBoundLoadBalancer:
         assert action.command == "add_service"
 
     def test_delete_service(
-        self, hetzner_client, response_delete_service, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_delete_service,
     ):
-        hetzner_client.request.return_value = response_delete_service
+        request_mock.return_value = response_delete_service
+
         service = LoadBalancerService(listen_port=12)
         action = bound_load_balancer.delete_service(service)
-        hetzner_client.request.assert_called_with(
-            json={"listen_port": 12},
-            url="/load_balancers/14/actions/delete_service",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/delete_service",
+            json={"listen_port": 12},
         )
 
         assert action.id == 13
@@ -175,13 +162,22 @@ class TestBoundLoadBalancer:
         ],
     )
     def test_add_target(
-        self, hetzner_client, response_add_target, bound_load_balancer, target, params
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_add_target,
+        target,
+        params,
     ):
-        hetzner_client.request.return_value = response_add_target
+        request_mock.return_value = response_add_target
+
         action = bound_load_balancer.add_target(target)
         params.update({"type": target.type})
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions/add_target", method="POST", json=params
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/load_balancers/14/actions/add_target",
+            json=params,
         )
 
         assert action.id == 13
@@ -212,17 +208,21 @@ class TestBoundLoadBalancer:
     )
     def test_remove_target(
         self,
-        hetzner_client,
-        response_remove_target,
+        request_mock: mock.MagicMock,
         bound_load_balancer,
+        response_remove_target,
         target,
         params,
     ):
-        hetzner_client.request.return_value = response_remove_target
+        request_mock.return_value = response_remove_target
+
         action = bound_load_balancer.remove_target(target)
         params.update({"type": target.type})
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions/remove_target", method="POST", json=params
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/load_balancers/14/actions/remove_target",
+            json=params,
         )
 
         assert action.id == 13
@@ -230,16 +230,23 @@ class TestBoundLoadBalancer:
         assert action.command == "remove_target"
 
     def test_update_service(
-        self, hetzner_client, response_update_service, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_update_service,
     ):
-        hetzner_client.request.return_value = response_update_service
+        request_mock.return_value = response_update_service
+
         new_health_check = LoadBalancerHealthCheck(
             protocol="http", port=13, interval=1, timeout=1, retries=1
         )
         service = LoadBalancerService(listen_port=12, health_check=new_health_check)
 
         action = bound_load_balancer.update_service(service)
-        hetzner_client.request.assert_called_with(
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/load_balancers/14/actions/update_service",
             json={
                 "listen_port": 12,
                 "health_check": {
@@ -250,8 +257,6 @@ class TestBoundLoadBalancer:
                     "retries": 1,
                 },
             },
-            url="/load_balancers/14/actions/update_service",
-            method="POST",
         )
 
         assert action.id == 13
@@ -259,15 +264,20 @@ class TestBoundLoadBalancer:
         assert action.command == "update_service"
 
     def test_change_algorithm(
-        self, hetzner_client, response_change_algorithm, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_change_algorithm,
     ):
-        hetzner_client.request.return_value = response_change_algorithm
+        request_mock.return_value = response_change_algorithm
+
         algorithm = LoadBalancerAlgorithm(type="round_robin")
         action = bound_load_balancer.change_algorithm(algorithm)
-        hetzner_client.request.assert_called_with(
-            json={"type": "round_robin"},
-            url="/load_balancers/14/actions/change_algorithm",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/change_algorithm",
+            json={"type": "round_robin"},
         )
 
         assert action.id == 13
@@ -275,16 +285,21 @@ class TestBoundLoadBalancer:
         assert action.command == "change_algorithm"
 
     def test_change_dns_ptr(
-        self, hetzner_client, response_change_reverse_dns_entry, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_change_reverse_dns_entry,
     ):
-        hetzner_client.request.return_value = response_change_reverse_dns_entry
+        request_mock.return_value = response_change_reverse_dns_entry
+
         action = bound_load_balancer.change_dns_ptr(
             ip="1.2.3.4", dns_ptr="lb1.example.com"
         )
-        hetzner_client.request.assert_called_with(
-            json={"dns_ptr": "lb1.example.com", "ip": "1.2.3.4"},
-            url="/load_balancers/14/actions/change_dns_ptr",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/change_dns_ptr",
+            json={"dns_ptr": "lb1.example.com", "ip": "1.2.3.4"},
         )
 
         assert action.id == 13
@@ -292,14 +307,19 @@ class TestBoundLoadBalancer:
         assert action.command == "change_dns_ptr"
 
     def test_change_protection(
-        self, hetzner_client, response_change_protection, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_change_protection,
     ):
-        hetzner_client.request.return_value = response_change_protection
+        request_mock.return_value = response_change_protection
+
         action = bound_load_balancer.change_protection(delete=True)
-        hetzner_client.request.assert_called_with(
-            json={"delete": True},
-            url="/load_balancers/14/actions/change_protection",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/change_protection",
+            json={"delete": True},
         )
 
         assert action.id == 13
@@ -307,12 +327,18 @@ class TestBoundLoadBalancer:
         assert action.command == "change_protection"
 
     def test_enable_public_interface(
-        self, response_enable_public_interface, hetzner_client, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_enable_public_interface,
     ):
-        hetzner_client.request.return_value = response_enable_public_interface
+        request_mock.return_value = response_enable_public_interface
+
         action = bound_load_balancer.enable_public_interface()
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions/enable_public_interface", method="POST"
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/load_balancers/14/actions/enable_public_interface",
         )
 
         assert action.id == 13
@@ -320,12 +346,18 @@ class TestBoundLoadBalancer:
         assert action.command == "enable_public_interface"
 
     def test_disable_public_interface(
-        self, response_disable_public_interface, hetzner_client, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_disable_public_interface,
     ):
-        hetzner_client.request.return_value = response_disable_public_interface
+        request_mock.return_value = response_disable_public_interface
+
         action = bound_load_balancer.disable_public_interface()
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions/disable_public_interface", method="POST"
+
+        request_mock.assert_called_with(
+            method="POST",
+            url="/load_balancers/14/actions/disable_public_interface",
         )
 
         assert action.id == 13
@@ -334,16 +366,18 @@ class TestBoundLoadBalancer:
 
     def test_attach_to_network(
         self,
-        response_attach_load_balancer_to_network,
-        hetzner_client,
+        request_mock: mock.MagicMock,
         bound_load_balancer,
+        response_attach_load_balancer_to_network,
     ):
-        hetzner_client.request.return_value = response_attach_load_balancer_to_network
+        request_mock.return_value = response_attach_load_balancer_to_network
+
         action = bound_load_balancer.attach_to_network(Network(id=1))
-        hetzner_client.request.assert_called_with(
-            json={"network": 1},
-            url="/load_balancers/14/actions/attach_to_network",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/attach_to_network",
+            json={"network": 1},
         )
 
         assert action.id == 13
@@ -351,26 +385,38 @@ class TestBoundLoadBalancer:
         assert action.command == "attach_to_network"
 
     def test_detach_from_network(
-        self, response_detach_from_network, hetzner_client, bound_load_balancer
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        response_detach_from_network,
     ):
-        hetzner_client.request.return_value = response_detach_from_network
+        request_mock.return_value = response_detach_from_network
+
         action = bound_load_balancer.detach_from_network(Network(id=1))
-        hetzner_client.request.assert_called_with(
-            json={"network": 1},
-            url="/load_balancers/14/actions/detach_from_network",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/detach_from_network",
+            json={"network": 1},
         )
 
         assert action.id == 13
         assert action.progress == 100
         assert action.command == "detach_from_network"
 
-    def test_change_type(self, hetzner_client, bound_load_balancer, generic_action):
-        hetzner_client.request.return_value = generic_action
+    def test_change_type(
+        self,
+        request_mock: mock.MagicMock,
+        bound_load_balancer,
+        action_response,
+    ):
+        request_mock.return_value = action_response
+
         action = bound_load_balancer.change_type(LoadBalancerType(name="lb21"))
-        hetzner_client.request.assert_called_with(
-            url="/load_balancers/14/actions/change_type",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/14/actions/change_type",
             json={"load_balancer_type": "lb21"},
         )
 
@@ -380,14 +426,22 @@ class TestBoundLoadBalancer:
 
 class TestLoadBalancerslient:
     @pytest.fixture()
-    def load_balancers_client(self):
-        return LoadBalancersClient(client=mock.MagicMock())
+    def load_balancers_client(self, client: Client):
+        return LoadBalancersClient(client)
+
+    def test_get_by_id(
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        response_load_balancer,
+    ):
+        request_mock.return_value = response_load_balancer
 
-    def test_get_by_id(self, load_balancers_client, response_load_balancer):
-        load_balancers_client._client.request.return_value = response_load_balancer
         bound_load_balancer = load_balancers_client.get_by_id(1)
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/1", method="GET"
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/load_balancers/1",
         )
         assert bound_load_balancer._client is load_balancers_client
         assert bound_load_balancer.id == 4711
@@ -410,14 +464,20 @@ class TestLoadBalancerslient:
         ],
     )
     def test_get_list(
-        self, load_balancers_client, response_simple_load_balancers, params
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        response_simple_load_balancers,
+        params,
     ):
-        load_balancers_client._client.request.return_value = (
-            response_simple_load_balancers
-        )
+        request_mock.return_value = response_simple_load_balancers
+
         result = load_balancers_client.get_list(**params)
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers", method="GET", params=params
+
+        request_mock.assert_called_with(
+            method="GET",
+            url="/load_balancers",
+            params=params,
         )
 
         bound_load_balancers = result.load_balancers
@@ -440,17 +500,22 @@ class TestLoadBalancerslient:
         "params", [{"name": "loadbalancer1", "label_selector": "label1"}, {}]
     )
     def test_get_all(
-        self, load_balancers_client, response_simple_load_balancers, params
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        response_simple_load_balancers,
+        params,
     ):
-        load_balancers_client._client.request.return_value = (
-            response_simple_load_balancers
-        )
+        request_mock.return_value = response_simple_load_balancers
+
         bound_load_balancers = load_balancers_client.get_all(**params)
 
         params.update({"page": 1, "per_page": 50})
 
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers", method="GET", params=params
+        request_mock.assert_called_with(
+            method="GET",
+            url="/load_balancers",
+            params=params,
         )
 
         assert len(bound_load_balancers) == 2
@@ -466,34 +531,45 @@ class TestLoadBalancerslient:
         assert bound_load_balancer2.id == 4712
         assert bound_load_balancer2.name == "Web Frontend2"
 
-    def test_get_by_name(self, load_balancers_client, response_simple_load_balancers):
-        load_balancers_client._client.request.return_value = (
-            response_simple_load_balancers
-        )
+    def test_get_by_name(
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        response_simple_load_balancers,
+    ):
+        request_mock.return_value = response_simple_load_balancers
+
         bound_load_balancer = load_balancers_client.get_by_name("Web Frontend")
 
         params = {"name": "Web Frontend"}
 
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers", method="GET", params=params
+        request_mock.assert_called_with(
+            method="GET",
+            url="/load_balancers",
+            params=params,
         )
 
         assert bound_load_balancer._client is load_balancers_client
         assert bound_load_balancer.id == 4711
         assert bound_load_balancer.name == "Web Frontend"
 
-    def test_create(self, load_balancers_client, response_create_load_balancer):
-        load_balancers_client._client.request.return_value = (
-            response_create_load_balancer
-        )
+    def test_create(
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        response_create_load_balancer,
+    ):
+        request_mock.return_value = response_create_load_balancer
+
         response = load_balancers_client.create(
             "my-balancer",
             load_balancer_type=LoadBalancerType(name="lb11"),
             location=Location(id=1),
         )
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers",
             json={"name": "my-balancer", "load_balancer_type": "lb11", "location": 1},
         )
 
@@ -508,15 +584,21 @@ class TestLoadBalancerslient:
         [LoadBalancer(id=1), BoundLoadBalancer(mock.MagicMock(), dict(id=1))],
     )
     def test_change_type_with_load_balancer_type_name(
-        self, load_balancers_client, load_balancer, generic_action
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        load_balancer,
+        action_response,
     ):
-        load_balancers_client._client.request.return_value = generic_action
+        request_mock.return_value = action_response
+
         action = load_balancers_client.change_type(
             load_balancer, LoadBalancerType(name="lb11")
         )
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/1/actions/change_type",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/1/actions/change_type",
             json={"load_balancer_type": "lb11"},
         )
 
@@ -528,67 +610,23 @@ class TestLoadBalancerslient:
         [LoadBalancer(id=1), BoundLoadBalancer(mock.MagicMock(), dict(id=1))],
     )
     def test_change_type_with_load_balancer_type_id(
-        self, load_balancers_client, load_balancer, generic_action
+        self,
+        request_mock: mock.MagicMock,
+        load_balancers_client: LoadBalancersClient,
+        load_balancer,
+        action_response,
     ):
-        load_balancers_client._client.request.return_value = generic_action
+        request_mock.return_value = action_response
+
         action = load_balancers_client.change_type(
             load_balancer, LoadBalancerType(id=1)
         )
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/1/actions/change_type",
+
+        request_mock.assert_called_with(
             method="POST",
+            url="/load_balancers/1/actions/change_type",
             json={"load_balancer_type": 1},
         )
 
         assert action.id == 1
         assert action.progress == 0
-
-    def test_actions_get_by_id(self, load_balancers_client, response_get_actions):
-        load_balancers_client._client.request.return_value = {
-            "action": response_get_actions["actions"][0]
-        }
-        action = load_balancers_client.actions.get_by_id(13)
-
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/actions/13", method="GET"
-        )
-
-        assert isinstance(action, BoundAction)
-        assert action._client == load_balancers_client._client.actions
-        assert action.id == 13
-        assert action.command == "change_protection"
-
-    def test_actions_get_list(self, load_balancers_client, response_get_actions):
-        load_balancers_client._client.request.return_value = response_get_actions
-        result = load_balancers_client.actions.get_list()
-
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/actions",
-            method="GET",
-            params={},
-        )
-
-        actions = result.actions
-        assert result.meta is not None
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == load_balancers_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "change_protection"
-
-    def test_actions_get_all(self, load_balancers_client, response_get_actions):
-        load_balancers_client._client.request.return_value = response_get_actions
-        actions = load_balancers_client.actions.get_all()
-
-        load_balancers_client._client.request.assert_called_with(
-            url="/load_balancers/actions",
-            method="GET",
-            params={"page": 1, "per_page": 50},
-        )
-
-        assert len(actions) == 1
-        assert isinstance(actions[0], BoundAction)
-        assert actions[0]._client == load_balancers_client._client.actions
-        assert actions[0].id == 13
-        assert actions[0].command == "change_protection"
